
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    print qq{1..0 # SKIP these tests are for testing by the author\n};
    exit
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007006
use Test::Spelling 0.17;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( . ) );
__DATA__
Bitsize
Bitsizes
Crypt
Cryptographic
Diffie
Elgamal
FastPrime
Legge
Maurer
Menezes
Mhz
Oorschot
PII
Prakash
Primes
RSA
Relprime
Reprime
Rq
TODO
Ueli
Vanstone
Ved
Vipul
bin
bitsize
codebase
cryptosystems
largeprimes
lib
mail
maxfact
